@@ -242,10 +242,12 @@ sub displayHTML {
 				)."</i>";
 	}
 
-	my $kind = ($type eq 'directory')
-			? 'dirPart'
-			: 'regPart';
-	my $partBox = [ $kind, $rt ];
+	my $color = ($type eq 'directory')
+			? $FAQ::OMatic::Config::directoryPartColor
+			: $FAQ::OMatic::Config::regularPartColor;
+	my $partBox = { 'type'=>'three',
+				'text'=>$rt,
+				'color'=>$color };
 	# that's the end of the main part content
 
 	if ($params->{'showEditCmds'} and $item->ordinaryItem()) {
@@ -254,15 +256,16 @@ sub displayHTML {
 		my @rightEdits = ();
 		my @belowEdits = ();
 
-		push @rightEdits, ['edit', FAQ::OMatic::button(
+		push @rightEdits, {'text'=>FAQ::OMatic::button(
 			FAQ::OMatic::makeAref('-command'=>'editPart',
 				'-params'=>$params,
 				'-changedParams'=>{'file'=>$filename,
 							'partnum'=>$partnum,
 							'checkSequenceNumber'=>$item->{'SequenceNumber'}}),
 			"Edit This Text",
-			"$aoc-edit-part", $params)];
-		push @rightEdits, ['edit', FAQ::OMatic::button(
+			"$aoc-edit-part", $params),
+				'size'=>'edit'};
+		push @rightEdits, {'text'=>FAQ::OMatic::button(
 			FAQ::OMatic::makeAref('-command'=>'editPart',
 				'-params'=>$params,
 				'-changedParams'=>{'file'=>$filename,
@@ -271,9 +274,10 @@ sub displayHTML {
 							'_duplicate'=>1,
 							'checkSequenceNumber'=>$item->{'SequenceNumber'}}),
 			"Duplicate This Text",
-			"$aoc-dup-part", $params)];
+			"$aoc-dup-part", $params),
+				'size'=>'edit'};
 		if ($type ne 'directory') {
-			push @rightEdits, ['edit', FAQ::OMatic::button(
+			push @rightEdits, {'text'=>FAQ::OMatic::button(
 				FAQ::OMatic::makeAref('-command'=>'delPart',
 					'-params'=>$params,
 					'-changedParams'=>{"file"=>$filename,
@@ -281,11 +285,12 @@ sub displayHTML {
 						'checkSequenceNumber'=>$item->{'SequenceNumber'}}
 				),
 			"Remove This Text",
-			"$aoc-del-part", $params)];
+			"$aoc-del-part", $params),
+				'size'=>'edit'};
 		} elsif (scalar($self->getChildren())==0) {
 			# directory, but has no children -- can just delete directory.
 			# this is a minor variation on Item's Convert to Answer.
-			push @rightEdits, ['edit', FAQ::OMatic::button(
+			push @rightEdits, {'text'=>FAQ::OMatic::button(
 				FAQ::OMatic::makeAref('-command'=>'submitCatToAns',
 					'-params'=>$params,
 					'-changedParams'=>{"file"=>$filename,
@@ -293,36 +298,40 @@ sub displayHTML {
 						'checkSequenceNumber'=>$item->{'SequenceNumber'}}
 				),
 			"Remove This Text",
-			"$aoc-del-part", $params)];
+			"$aoc-del-part", $params),
+				'size'=>'edit'};
 		}
 
 		my @baglist = $self->getBags();
 		if (scalar(@baglist)==1) {
-			push @rightEdits, ['edit', FAQ::OMatic::button(
+			push @rightEdits, {'text'=>FAQ::OMatic::button(
 				FAQ::OMatic::makeAref('-command'=>'editBag',
 					'-params'=>$params,
 					'-changedParams'=>{'file'=>$filename,
 						'_target'=>$baglist[0]}),
-				"Replace $baglist[0]<br>with new upload")];
+				"Replace $baglist[0]<br>with new upload"),
+					'size'=>'edit'};
 		} elsif (scalar(@baglist)>1) {
-			push @rightEdits, ['edit', FAQ::OMatic::button(
+			push @rightEdits, {'edit'=>FAQ::OMatic::button(
 				FAQ::OMatic::makeAref('-command'=>'selectBag',
 					'-params'=>$params,
 					'-changedParams'=>{'file'=>$filename}),
-				"Select bag to replace with new upload")];
+				"Select bag to replace with new upload"),
+					'size'=>'edit'};
 		}
 
-		push @rightEdits, ['edit', FAQ::OMatic::button(
+		push @rightEdits, {'text'=>FAQ::OMatic::button(
 			FAQ::OMatic::makeAref('-command'=>'editBag',
 				'-params'=>$params,
 				'-changedParams'=>{'file'=>$filename,
 					'partnum'=>$partnum}),
-			"Upload New Bag Here")];
+			"Upload New Bag Here"),
+				'size'=>'edit'};
 
 		# separate block of editing commands that don't apply to a specific
 		# part, but their position between parts is relevant
-		push @belowEdits, '';
-		push @belowEdits, ['edit', FAQ::OMatic::button(
+		push @belowEdits, {'text'=>''};
+		push @belowEdits, {'text'=>FAQ::OMatic::button(
 			FAQ::OMatic::makeAref('-command'=>'editPart',
 				'-params'=>$params,
 				'-changedParams'=>{'file'=>$filename,
@@ -330,8 +339,9 @@ sub displayHTML {
 							'_insertpart'=>1,
 							'checkSequenceNumber'=>$item->{'SequenceNumber'}}),
 				"Insert Text Here",
-			"$aoc-ins-part", $params)];
-		push @belowEdits, ['edit', FAQ::OMatic::button(
+			"$aoc-ins-part", $params),
+				'size'=>'edit'};
+		push @belowEdits, {'text'=>FAQ::OMatic::button(
 			FAQ::OMatic::makeAref('-command'=>'editPart',
 				'-params'=>$params,
 				'-changedParams'=>{'file'=>$filename,
@@ -340,13 +350,21 @@ sub displayHTML {
 							'_upload'=>1,
 							'checkSequenceNumber'=>$item->{'SequenceNumber'}}),
 				"Insert Uploaded Text Here",
-			"$aoc-ins-part", $params)];
+			"$aoc-ins-part", $params),
+				'size'=>'edit'};
 
-		return [ $partBox, \@rightEdits, \@belowEdits ];
+		return { 'type'=>'three',
+			'body'=>$partBox,
+			'editbody'=>\@rightEdits,
+			'afterbody'=>\@belowEdits,
+			'id'=>'generated by Part::displayHTML'};
 	}
 
 	# no editing boxes
-	return [ [ $partBox ] ];
+	return { 'type'=>'wide',
+		'text'=>$partBox->{'text'},
+		'color'=>$partBox->{'color'}
+		};
 }
 
 sub displayPartEditor {
@@ -365,6 +383,7 @@ sub displayPartEditor {
 						'-params'=>$params,
 						'-changedParams'=>{'partnum'=>$partnum},
 						'-refType'=>'POST',
+						'-multipart'=>($params->{'_upload'} ? 1 : ''),
 						'-saveTransients'=>1);
 
 	$rt.="<table><tr>\n";
@@ -373,6 +392,8 @@ sub displayPartEditor {
 		.$item->{'SequenceNumber'}."\">\n";
 
 	if (not $params->{'_upload'}) {
+		# Regular input screen -- provide a <textarea> to edit part's text
+		#
 		# no text boxes wrap anymore -- it breaks long URLs.
 		# THANKS: to Billy Naylor <banjo@actrix.gen.nz> for the fix
 		# THANKS: to "Alan R. Zimmerman" <mailto:alanz@mdhost.cse.tek.com>) for
